# v0.2.2
* Add true lineno in warning when declaring empty option group
* Update readme

# v0.2.1
* Use RuntimeWarning and stacklevel 2 when declaring empty option group
* Update readme

# v0.2.0
* Implement `RequiredMutuallyExclusiveOptionGroup` class instead of `required` argument for `MutuallyExclusiveOptionGroup`
* Add tests with 100% coverage
* Update readme

# v0.1.0
* First public release
